@@ -18,6 +18,7 @@
 #include <DStyle>
 #include <DApplication>
 #include <DSysInfo>
+#include <DPaletteHelper>
 
 #include <QItemSelectionModel>
 #include <QMargins>
@@ -122,13 +123,18 @@ void LogListDelegate::hideTooltipImmediately()
 LogListView::LogListView(QWidget *parent)
     : DListView(parent)
 {
+    qDebug() << "LogListView constructor entered";
     initUI();
     setContextMenuPolicy(Qt::CustomContextMenu);
     connect(this, &LogListView::customContextMenuRequested, this, &LogListView::requestshowRightMenu);
-    //DGuiApplicationHelper::ColorType ct = DApplicationHelper::instance()->themeType();
+    //DGuiApplicationHelper::ColorType ct = DGuiApplicationHelper::instance()->themeType();
 
     m_rightClickTriggerShortCut = new QShortcut(this);
-    m_rightClickTriggerShortCut->setKey(Qt::ALT + Qt::Key_M);
+    #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+        m_rightClickTriggerShortCut->setKey(Qt::ALT + Qt::Key_M);
+    #else
+        m_rightClickTriggerShortCut->setKey(QKeyCombination(Qt::ALT, Qt::Key_M));
+    #endif
     m_rightClickTriggerShortCut->setContext(Qt::WidgetShortcut);
     m_rightClickTriggerShortCut->setAutoRepeat(false);
     connect(m_rightClickTriggerShortCut, &QShortcut::activated, this, [this] {
@@ -150,6 +156,7 @@ LogListView::LogListView(QWidget *parent)
  */
 void LogListView::initUI()
 {
+    qDebug() << "LogListView::initUI() entered";
     this->setMinimumWidth(150);
     this->setEditTriggers(QAbstractItemView::NoEditTriggers);
     this->setItemDelegate(new LogListDelegate(this));
@@ -308,17 +315,17 @@ void LogListView::initUI()
         initCustomLogItem();
     }
 
-    // 审计日志文件存在，才加载和显示审计日志模块（审计日志文件需要root权限访问，因此在service服务中判断审计日志文件是否存在）
-    if (DLDBusHandler::instance(this)->isFileExist(AUDIT_TREE_DATA)) {
-        item = new QStandardItem(QIcon::fromTheme("dp_customlog"), DApplication::translate("Tree", "Audit Log"));
-        setIconSize(QSize(ICON_SIZE, ICON_SIZE));
-        item->setToolTip(DApplication::translate("Tree", "Audit Log"));
-        item->setData(AUDIT_TREE_DATA, ITEM_DATE_ROLE);
-        item->setSizeHint(QSize(ITEM_WIDTH, ITEM_HEIGHT));
-        item->setData(VListViewItemMargin, Dtk::MarginsRole);
-        m_pModel->appendRow(item);
-        m_logTypes.push_back(AUDIT_TREE_DATA);
-    }
+    // 审计日志 （因dbus安全整改要求，isFileExist接口需要进行polkit鉴权，因此调整为程序启动时默认显示审计日志）
+    item = new QStandardItem(QIcon::fromTheme("dp_customlog"), DApplication::translate("Tree", "Audit Log"));
+    setIconSize(QSize(ICON_SIZE, ICON_SIZE));
+    item->setToolTip(DApplication::translate("Tree", "Audit Log"));
+    item->setData(AUDIT_TREE_DATA, ITEM_DATE_ROLE);
+    item->setSizeHint(QSize(ITEM_WIDTH, ITEM_HEIGHT));
+    item->setData(VListViewItemMargin, Dtk::MarginsRole);
+    m_pModel->appendRow(item);
+    m_logTypes.push_back(AUDIT_TREE_DATA);
+
+    DLDBusHandler::instance(this)->whiteListOutPaths();
 
     // set first item is select when app start
     if (m_pModel->rowCount() > 0) {
@@ -340,6 +347,25 @@ void LogListView::initCustomLogItem()
     m_pModel->appendRow(m_customLogItem);
 }
 
+QStringList LogListView::getAllFiles(const QString &file)
+{
+    QStringList files;
+    if (file.contains("*")) {
+        QString path = file.left(file.lastIndexOf('/'));
+        QDir dir(path);
+        QStringList filters;
+        filters << file.split('/').last();
+        files = dir.entryList(filters, QDir::Files);
+
+        for (auto &file : files) {
+            file = path + "/" + file;
+        }
+    } else {
+        files << file;
+    }
+    return files;
+}
+
 void LogListView::setDefaultSelect()
 {
     setCurrentIndex(currentIndex());
@@ -363,11 +389,10 @@ bool LogListView::isFileExist(const QString &iFile)
  */
 void LogListView::paintEvent(QPaintEvent *event)
 {
-    DPalette pa = DApplicationHelper::instance()->palette(this);
+    DPalette pa = DPaletteHelper::instance()->palette(this);
     pa.setBrush(DPalette::ItemBackground, pa.color(DPalette::Base));
-    pa.setBrush(DPalette::Background, pa.color(DPalette::Base));
+    // pa.setBrush(DPalette::Background, pa.color(DPalette::Base));
     this->setPalette(pa);
-    DApplicationHelper::instance()->setPalette(this, pa);
 
     this->setAutoFillBackground(true);
 
@@ -383,11 +408,13 @@ void LogListView::currentChanged(const QModelIndex &current, const QModelIndex &
 {
     PERF_PRINT_BEGIN("POINT-03", "");
     if (current.row() < 0) {
+        qDebug() << "Invalid current row, exiting currentChanged";
         return;
     }
 
     emit itemChanged(current);
     DListView::currentChanged(current, previous);
+    qDebug() << "LogListView::currentChanged() exited";
 }
 
 /**
@@ -399,17 +426,19 @@ void LogListView::truncateFile(QString path_)
 {
     QProcess prc;
     if (path_ == KERN_TREE_DATA || path_ == BOOT_TREE_DATA || path_ == DPKG_TREE_DATA || path_ == KWIN_TREE_DATA) {
-        prc.start("pkexec", QStringList() << "logViewerTruncate" << path_.append("*"));
+        QStringList files = getAllFiles(path_.append("*"));
+        prc.start("pkexec", QStringList() << "logViewerTruncate" << files.join(' '));
     } else if (path_ == XORG_TREE_DATA) {
         path_ = "/var/log/Xorg*.log*";
-        prc.start("pkexec", QStringList() << "logViewerTruncate" << path_);
+        QStringList files = getAllFiles(path_);
+        prc.start("pkexec", QStringList() << "logViewerTruncate" << files.join(' '));
     } else if (path_ == DNF_TREE_DATA) {
         path_ = "/var/log/dnf*.log*";
-        prc.start("pkexec", QStringList() << "logViewerTruncate" << path_);
+        QStringList files = getAllFiles(path_);
+        prc.start("pkexec", QStringList() << "logViewerTruncate" << files.join(' '));
     } else {
-        QStringList arg;
-        arg << "-c" << QString("truncate -s 0 %1").arg(path_.append("*"));
-        prc.start("/bin/bash", arg);
+        QStringList files = getAllFiles(path_.append("*"));
+        prc.start("pkexec", QStringList() << "logViewerTruncate" << files.join(' '));
     }
 
     prc.waitForFinished();
@@ -428,7 +457,9 @@ void LogListView::slot_getAppPath(int id, const QString &app)
     if (!appConfig.isValid())
         g_path = "";
     else {
-        std::vector<SubModuleConfig> vSubmodules = appConfig.subModules.toVector().toStdVector();
+        // std::vector<SubModuleConfig> vSubmodules = appConfig.subModules.toVector().toStdVector();
+        QVector<SubModuleConfig> qSubmodules = appConfig.subModules.toVector();
+        std::vector<SubModuleConfig> vSubmodules(qSubmodules.begin(), qSubmodules.end());
         auto it = std::find_if(vSubmodules.begin(), vSubmodules.end(), [=](SubModuleConfig submodule) {
             return submodule.logType == "file" && submodule.name == appConfig.name;
         });
@@ -449,6 +480,7 @@ Qt::FocusReason LogListView::focusReson()
 
 void LogListView::showRightMenu(const QPoint &pos, bool isUsePoint)
 {
+    qDebug() << "LogListView::showRightMenu() entered";
     QModelIndex idx = this->currentIndex();
     QString pathData = idx.data(ITEM_DATE_ROLE).toString();
     if (!this->selectionModel()->selectedIndexes().empty()) {
